mc_core

Enum Joint

pub enum Joint {
    Simple {
        id: usize,
        params: ServoParams,
        state: ServoState,
        axis: UrdfAxis,
    },
    Face {
        id: usize,
        params: ServoParams,
        state: ServoState,
        axis: NormalizedAxis,
    },
    Complex {
        id_a: usize,
        id_b: usize,
        params: ServoParams,
        state_a: ServoState,
        state_b: ServoState,
        axis_theta: UrdfAxis,
        axis_phi: UrdfAxis,
    },
    KneesHips {
        id_knee0: usize,
        id_knee1: usize,
        id_hip0: usize,
        id_hip1: usize,
        params: ServoParams,
        state_knee0: ServoState,
        state_knee1: ServoState,
        state_hip0: ServoState,
        state_hip1: ServoState,
        pid: Pid,
        axis: UrdfAxis,
        hips_name: String,
    },
}
simple, face, complex or knees/hips joint

Variants



Simple

simple joint, one URDF axis corresponds to one servo

Fields



Face

face joint, one normalized axis corresponds to one servo



Complex

complex joint, two URDF axes correspond to two servos, as described by the unified arm assemblies

Fields

id_a: usize
id_b: usize
state_a: ServoState
state_b: ServoState
axis_theta: UrdfAxis
axis_phi: UrdfAxis


KneesHips

knees/hips joint, one URDF axis corresponds to all four knee and hip servos, controlled via a PID controller

Fields

id_knee0: usize
id_knee1: usize
id_hip0: usize
id_hip1: usize
state_knee0: ServoState
state_knee1: ServoState
state_hip0: ServoState
state_hip1: ServoState
pid: Pid
hips_name: String

Implementations

Source

impl Joint

pub fn new_simple( name: &str, id: usize, ratio: f32, urdf_anchor: f32, min_voltage: f32, max_voltage: f32, max_temperature: f32, ) -> Self

Create new simple joint.

Arguments
  • name - name of the axis
  • id - servo ID
  • ratio - angle ratio of external gear or belt assembly
  • urdf_anchor - calibration anchor of the axis
  • min_voltage - minimum voltage
  • max_voltage - maximum voltage
  • max_temperature - maximum temperature
pub fn new_face( name: &str, id: usize, min_voltage: f32, max_voltage: f32, max_temperature: f32, ) -> Self

Create new face joint.

Arguments
  • name - name of the axis
  • id - servo ID
  • min_voltage - minimum voltage
  • max_voltage - maximum voltage
  • max_temperature - maximum temperature
pub fn new_complex( name_theta: &str, name_phi: &str, id_a: usize, id_b: usize, ratio: f32, urdf_anchor_theta: f32, urdf_anchor_phi: f32, min_voltage: f32, max_voltage: f32, max_temperature: f32, ) -> Self

Create new complex joint.

Arguments
  • name_theta - name of the theta axis
  • name_phi - name of the phi axis
  • id_a - ID of servo A
  • id_b - ID of servo B
  • ratio - angle ratio of external gear or belt assembly
  • urdf_anchor_theta - calibration anchor of the theta axis
  • urdf_anchor_phi - calibration anchor of the phi axis
  • min_voltage - minimum voltage
  • max_voltage - maximum voltage
  • max_temperature - maximum temperature
pub fn new_knees_hips( knees_name: &str, hips_name: &str, id_knee0: usize, id_knee1: usize, id_hip0: usize, id_hip1: usize, ratio: f32, urdf_anchor: f32, min_voltage: f32, max_voltage: f32, max_temperature: f32, ) -> Self

Create new knees/hips joint.

Arguments
  • knees_name - name of the knees axis
  • hips_name - name of the hips axis
  • id_knee0 - ID of servo knee0
  • id_knee1 - ID of servo knee1
  • id_hip0 - ID of servo hip0
  • id_hip1 - ID of servo hip1
  • ratio - angle ratio of external gear or belt assembly
  • urdf_anchor - calibration anchor of the axis
  • min_voltage - minimum voltage
  • max_voltage - maximum voltage
  • max_temperature - maximum temperature
pub fn add_to_bus(&self, bus: &mut ServoBus)

Add the joint to a servo bus.

Arguments
  • bus - servo bus
pub fn update(&mut self, bus: &mut ServoBus, torque: bool)

Update the joint.

Arguments
  • bus - servo bus
  • torque - whether to enable torque
pub fn has_id(&self, id: usize) -> bool

Check if the joint manages a given servo ID.

Arguments
  • id - servo ID
pub fn has_axis(&self, axis_name: &str) -> bool

Check if the joint manages a given axis.

Arguments
  • axis_name - name of the axis
pub fn to_bson(&self) -> Bson

Convert the joint to a BSON document.

pub fn push_axis_names(&self, axis_names: &mut Vec<String>)

Push the names of the axes managed by the joint to a vector.

Arguments
  • axis_names - vector to push the axis names to
pub fn push_axis_positions(&self, axis_positions: &mut Vec<f64>)

Push the positions of the axes managed by the joint to a vector

Arguments
  • axis_positions - vector to push the axis positions to
pub fn push_axis_goals(&self, axis_goals: &mut Vec<f64>)

Push the goals of the axes managed by the joint to a vector.

Arguments
  • axis_goals - vector to push the axis goals to