mc_core

Enum ServoBus

pub enum ServoBus {
    Feetech(Bus),
}
servo bus

Variants



Feetech(Bus)

Feetech implementation

Implementations

Source

impl ServoBus

pub fn port_path(&self) -> &Path

Get the path of the used serial port.

pub fn add_servo(&mut self, id: usize, params: &ServoParams)

Add a new servo to the bus.

Arguments
  • id - ID of the servo to add
  • params - initial parameters for the servo
pub fn remove_servo(&mut self, id: usize)

Remove a servo from the bus.

Arguments
  • id - ID of the servo to remove
pub async fn reset_servo(&mut self, id: usize) -> Result<()>

Reset a servo and make the current position 0.

Arguments
  • id - ID of the servo to reset
Returns

Ok(()) if the servo was reset successfully, Err(e) otherwise

pub fn set_servo_params( &mut self, id: usize, params: &ServoParams, ) -> Result<()>

Set new parameters for a servo.

Arguments
  • id - ID of the servo to set parameters for
  • params - new parameters for the servo
Returns

Ok(()) if the parameters were set successfully, Err(e) otherwise

pub fn servo_goals_mut(&mut self, id: usize) -> Option<&mut ServoGoals>

Get mutable reference to the goals for a servo.

Arguments
  • id - ID of the servo to get goals for
Returns

mutable reference to the goals for the servo, or None if the servo does not exist

pub fn servo_state(&self, id: usize) -> Option<&ServoState>

Get reference to the state of a servo.

Arguments
  • id - ID of the servo to get state for
Returns

reference to the state of the servo, or None if the servo does not exist

pub fn servo_params_mut(&mut self, id: usize) -> Option<&mut ServoParams>

Get mutable reference to the parameters for a servo.

Arguments
  • id - ID of the servo to get parameters for
Returns

mutable reference to the parameters for the servo, or None if the servo does not exist

pub async fn init_loop(&mut self) -> Result<()>

Initialize the update loop.

Returns

Ok(()) if the loop was initialized successfully, Err(e) otherwise

pub async fn update_recv(&mut self) -> Result<()>

Receive the state of all servos, reinitialize up to one failing servo.

Returns

Ok(()) if the state was received successfully, Err(e) otherwise

pub async fn update_send(&mut self) -> Result<()>

Write the goals to all servos, request to read the state of all servos.

Returns

Ok(()) if the goals were sent successfully, Err(e) otherwise