pub enum Joint {
Simple {
id: usize,
params: ServoParams,
state: ServoState,
axis: UrdfAxis,
},
Face {
id: usize,
params: ServoParams,
state: ServoState,
axis: NormalizedAxis,
},
Complex {
id_a: usize,
id_b: usize,
params: ServoParams,
state_a: ServoState,
state_b: ServoState,
axis_theta: UrdfAxis,
axis_phi: UrdfAxis,
},
KneesHips {
id_knee0: usize,
id_knee1: usize,
id_hip0: usize,
id_hip1: usize,
params: ServoParams,
state_knee0: ServoState,
state_knee1: ServoState,
state_hip0: ServoState,
state_hip1: ServoState,
pid: Pid,
axis: UrdfAxis,
hips_name: String,
},
}Expand description
simple, face, complex or knees/hips joint
Variants
Simple
simple joint, one URDF axis corresponds to one servo
Face
face joint, one normalized axis corresponds to one servo
Complex
complex joint, two URDF axes correspond to two servos, as described by the unified arm assemblies
KneesHips
knees/hips joint, one URDF axis corresponds to all four knee and hip servos, controlled via a PID controller
Fields

params: ServoParams
state_knee0: ServoState
state_knee1: ServoState
state_hip0: ServoState
state_hip1: ServoStateImplementations
Sourceimpl Joint
impl Joint
Sourcepub fn new_simple(
name: &str,
id: usize,
ratio: f32,
urdf_anchor: f32,
min_voltage: f32,
max_voltage: f32,
max_temperature: f32,
) -> Self
pub fn new_simple( name: &str, id: usize, ratio: f32, urdf_anchor: f32, min_voltage: f32, max_voltage: f32, max_temperature: f32, ) -> Self
Create new simple joint.
Arguments
name- name of the axisid- servo IDratio- angle ratio of external gear or belt assemblyurdf_anchor- calibration anchor of the axismin_voltage- minimum voltagemax_voltage- maximum voltagemax_temperature- maximum temperature
Sourcepub fn new_face(
name: &str,
id: usize,
min_voltage: f32,
max_voltage: f32,
max_temperature: f32,
) -> Self
pub fn new_face( name: &str, id: usize, min_voltage: f32, max_voltage: f32, max_temperature: f32, ) -> Self
Create new face joint.
Arguments
name- name of the axisid- servo IDmin_voltage- minimum voltagemax_voltage- maximum voltagemax_temperature- maximum temperature
Sourcepub fn new_complex(
name_theta: &str,
name_phi: &str,
id_a: usize,
id_b: usize,
ratio: f32,
urdf_anchor_theta: f32,
urdf_anchor_phi: f32,
min_voltage: f32,
max_voltage: f32,
max_temperature: f32,
) -> Self
pub fn new_complex( name_theta: &str, name_phi: &str, id_a: usize, id_b: usize, ratio: f32, urdf_anchor_theta: f32, urdf_anchor_phi: f32, min_voltage: f32, max_voltage: f32, max_temperature: f32, ) -> Self
Create new complex joint.
Arguments
name_theta- name of the theta axisname_phi- name of the phi axisid_a- ID of servo Aid_b- ID of servo Bratio- angle ratio of external gear or belt assemblyurdf_anchor_theta- calibration anchor of the theta axisurdf_anchor_phi- calibration anchor of the phi axismin_voltage- minimum voltagemax_voltage- maximum voltagemax_temperature- maximum temperature
Sourcepub fn new_knees_hips(
knees_name: &str,
hips_name: &str,
id_knee0: usize,
id_knee1: usize,
id_hip0: usize,
id_hip1: usize,
ratio: f32,
urdf_anchor: f32,
min_voltage: f32,
max_voltage: f32,
max_temperature: f32,
) -> Self
pub fn new_knees_hips( knees_name: &str, hips_name: &str, id_knee0: usize, id_knee1: usize, id_hip0: usize, id_hip1: usize, ratio: f32, urdf_anchor: f32, min_voltage: f32, max_voltage: f32, max_temperature: f32, ) -> Self
Create new knees/hips joint.
Arguments
knees_name- name of the knees axiships_name- name of the hips axisid_knee0- ID of servo knee0id_knee1- ID of servo knee1id_hip0- ID of servo hip0id_hip1- ID of servo hip1ratio- angle ratio of external gear or belt assemblyurdf_anchor- calibration anchor of the axismin_voltage- minimum voltagemax_voltage- maximum voltagemax_temperature- maximum temperature
Sourcepub fn add_to_bus(&self, bus: &mut ServoBus)
pub fn add_to_bus(&self, bus: &mut ServoBus)
Sourcepub fn push_axis_names(&self, axis_names: &mut Vec<String>)
pub fn push_axis_names(&self, axis_names: &mut Vec<String>)
Push the names of the axes managed by the joint to a vector.
Arguments
axis_names- vector to push the axis names to
Sourcepub fn push_axis_positions(&self, axis_positions: &mut Vec<f64>)
pub fn push_axis_positions(&self, axis_positions: &mut Vec<f64>)
Push the positions of the axes managed by the joint to a vector
Arguments
axis_positions- vector to push the axis positions to
Sourcepub fn push_axis_goals(&self, axis_goals: &mut Vec<f64>)
pub fn push_axis_goals(&self, axis_goals: &mut Vec<f64>)
Push the goals of the axes managed by the joint to a vector.
Arguments
axis_goals- vector to push the axis goals to