pub enum ServoBus {
Feetech(Bus),
}Expand description
servo bus
Variants
Implementations
Sourceimpl ServoBus
impl ServoBus
Sourcepub fn add_servo(&mut self, id: usize, params: &ServoParams)
pub fn add_servo(&mut self, id: usize, params: &ServoParams)
Add a new servo to the bus.
Arguments
id- ID of the servo to addparams- initial parameters for the servo
Sourcepub fn remove_servo(&mut self, id: usize)
pub fn remove_servo(&mut self, id: usize)
Sourcepub async fn reset_servo(&mut self, id: usize) -> Result<()>
pub async fn reset_servo(&mut self, id: usize) -> Result<()>
Sourcepub fn set_servo_params(
&mut self,
id: usize,
params: &ServoParams,
) -> Result<()>
pub fn set_servo_params( &mut self, id: usize, params: &ServoParams, ) -> Result<()>
Sourcepub fn servo_goals_mut(&mut self, id: usize) -> Option<&mut ServoGoals>
pub fn servo_goals_mut(&mut self, id: usize) -> Option<&mut ServoGoals>
Sourcepub fn servo_state(&self, id: usize) -> Option<&ServoState>
pub fn servo_state(&self, id: usize) -> Option<&ServoState>
Sourcepub fn servo_params_mut(&mut self, id: usize) -> Option<&mut ServoParams>
pub fn servo_params_mut(&mut self, id: usize) -> Option<&mut ServoParams>
Sourcepub async fn init_loop(&mut self) -> Result<()>
pub async fn init_loop(&mut self) -> Result<()>
Initialize the update loop.
Returns
Ok(()) if the loop was initialized successfully, Err(e) otherwise
Sourcepub async fn update_recv(&mut self) -> Result<()>
pub async fn update_recv(&mut self) -> Result<()>
Receive the state of all servos, reinitialize up to one failing servo.
Returns
Ok(()) if the state was received successfully, Err(e) otherwise
Sourcepub async fn update_send(&mut self) -> Result<()>
pub async fn update_send(&mut self) -> Result<()>
Write the goals to all servos, request to read the state of all servos.
Returns
Ok(()) if the goals were sent successfully, Err(e) otherwise